@@ -3,6 +3,7 @@ import uuid
 from dataclasses import dataclass
 from typing import Any, List, Optional, TYPE_CHECKING, Tuple, Type, Union
 
+import sqlalchemy
 from pydantic import BaseModel, create_model
 from pydantic.typing import ForwardRef, evaluate_forwardref
 from sqlalchemy import UniqueConstraint
@@ -103,7 +104,7 @@ def populate_fk_params_based_on_to_model(
     )
     constraints = [
         ForeignKeyConstraint(
-            name=fk_string, ondelete=ondelete, onupdate=onupdate  # type: ignore
+            reference=fk_string, ondelete=ondelete, onupdate=onupdate, name=None
         )
     ]
     column_type = to_field.column_type
@@ -124,9 +125,10 @@ class ForeignKeyConstraint:
     to produce sqlalchemy.ForeignKeys
     """
 
-    name: str
-    ondelete: str
-    onupdate: str
+    reference: Union[str, sqlalchemy.Column]
+    name: Optional[str]
+    ondelete: Optional[str]
+    onupdate: Optional[str]
 
 
 def ForeignKey(  # noqa CFQ002
