@@ -1,3 +1,7 @@
+"""
+Contains set of fields/methods etc names that are used to bypass the checks in
+NewBaseModel __getattribute__ calls to speed the calls.
+"""
 quick_access_set = {
     "Config",
     "Meta",
@@ -33,7 +37,7 @@ quick_access_set = {
     "delete",
     "dict",
     "extract_related_names",
-    "from_dict",
+    "update_from_dict",
     "get_column_alias",
     "get_column_name_from_alias",
     "get_filtered_names_to_extract",
